@@ -1,6 +1,6 @@
 package UV::Util;
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -303,6 +303,16 @@ current process.
 This L<function|http://docs.libuv.org/en/latest/misc.html#c.uv_uptime>
 returns a float representing the current system uptime.
 
+=head2 version
+
+    use UV::Util;
+
+    say UV::Util::version();
+    # 1.9.1
+
+This L<function|http://docs.libuv.org/en/v1.x/version.html>
+returns the libUV version number as a string. Does not throw errors.
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2017, Chase Whitener.
